#!/bin/bash
##############################################################################
# TPCH Raw Data Generation 
##############################################################################

source ../params.conf

if [ $# -lt 1 ]; then
	echo "[ERROR] Insufficient # of params"
	echo "USAGE: `dirname $0`/$0 <scaleFactor> "
	exit 127
fi

scaleFactor=$1

### Check for cores per worker
if [ -z $coresPerWorker ]; then
	echo "[ERROR] Cores per worker was not configured"
	exit 127
fi

### Check for remote generating directory
if [ -z $remoteGenDir ]; then
	echo "[ERROR] Remote generating directory was not configured"
	exit 127
fi

### Check for  target path
if [ -z $targetPath ]; then
	echo "[ERROR] target path was not configured"
	exit 127
fi


### Check for workload -- a file with one row for a tpc-h table, each row with format <tblCode> <tblName> <#Chunks>
## Assume that all the nodes are uniformi. If no existing workload file is found, will generate one now -
## #Chunks = numHosts*coresPerWorker.

workFile=../workloads/tpch.workload.${scaleFactor}.lst

echo $workFile
#Clear existing workloads
rm -rf writeData.sh
rm -rf ${targetPath}/SF${scaleFactor}

###
#Creating Root Directory (if not existent)
echo "[INFO] Creating Root Directory (if not existent)"
mkdir -p ${targetPath}/SF${scaleFactor}

### Init Workloads
fileName=writeData.sh
echo "#!/bin/bash" >> $fileName
echo "  "  >> $fileName
echo "workDir=\`dirname \$0\`"  >> $fileName
echo "cd \$workDir"  >> $fileName
echo "export DSS_PATH=$remoteGenDir" >> $fileName
echo "source ../params.conf"  >> $fileName
echo "  "  >> $fileName

### Generate Workloads
while read line; do
	params=( $line )
	#Extracting Parameters
	#echo ${params[*]}
	tblCode=${params[0]}
	tblName=${params[1]}
	tblParts=${params[2]}
	echo "====$tblName==="
	mkdir -p ${targetPath}/SF${scaleFactor}/$tblName
	# Assigning workload in round-robin fashion
	partsDone=1
	while [ $partsDone -le $tblParts ]; do
		#echo "write part $partsDone of $tblParts for $tblName (dbgen : $tblCode) on HostID="$worker
		if [ $tblParts -gt 1 ]; then
			echo "rm -rf $remoteGenDir/${tblName}.tbl.${partsDone}" >> writeData.sh
			echo "mkfifo $remoteGenDir/${tblName}.tbl.${partsDone}" >> writeData.sh
			echo "$remoteGenDir/dbgen -s $scaleFactor -T $tblCode -S $partsDone -C $tblParts -f &" >> writeData.sh
			echo "$remoteGenDir/uploadAndDelete.sh $remoteGenDir/${tblName}.tbl.${partsDone} ${targetPath}/SF${scaleFactor}/$tblName $tblParts &" >> writeData.sh
		else
			echo "rm -rf $remoteGenDir/${tblName}.tbl" >> writeData.sh
			echo "mkfifo $remoteGenDir/${tblName}.tbl" >> writeData.sh
			echo "$remoteGenDir/dbgen -s $scaleFactor -T $tblCode -C $tblParts -f &" >> writeData.sh
			echo "$remoteGenDir/uploadAndDelete.sh $remoteGenDir/${tblName}.tbl ${targetPath}/SF${scaleFactor}/$tblName $tblParts &" >> writeData.sh
		fi
		echo "$remoteGenDir/wait4process.sh dbgen \$threadsPerWorker " >> writeData.sh
		echo "   " >> writeData.sh

		let partsDone=1+$partsDone
	done
done <$workFile;


echo "[INFO] Started Generation @ "`date +%H:%M:%S`
startTime=`date +%s`

### Distribute & Execute workloads

chmod 755 writeData.sh
sh writeData.sh &


### Waiting for completion
echo "[INFO] Waiting until completion..."
wait
endTime=`date +%s`
echo "[INFO] Completed Generation @ "`date +%H:%M:%S`
echo "[INFO] Generated and loaded SF"${scaleFactor}" in "`echo $endTime - $startTime |bc`" sec"
